@@ -30,7 +30,6 @@
 
 #include "eog-list-store.h"
 #include "eog-image.h"
-#include "eog-dialog.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -127,7 +126,7 @@ gboolean      eog_window_is_empty 	(EogWindow       *window);
 gboolean      eog_window_is_not_initializing (const EogWindow *window);
 
 void          eog_window_reload_image (EogWindow *window);
-EogDialog    *eog_window_get_properties_dialog (EogWindow *window);
+GtkWidget    *eog_window_get_properties_dialog (EogWindow *window);
 
 void          eog_window_show_about_dialog (EogWindow    *window);
 void          eog_window_show_preferences_dialog (EogWindow *window);
